{config, pkgs, ...}:

{
  home.username = "ale";
  home.homeDirectory = "/home/ale";
  nixpkgs.config.allowUnfree = false;

  xdg.enable = true; # Let's home-manager manage xdg variables
   
  home.packages = [
    pkgs.btop
    pkgs.hyfetch
    pkgs.distrobox
    
    pkgs.rofi-wayland
    pkgs.waybar
    pkgs.swaybg
        
    pkgs.paper-icon-theme
    pkgs.adw-gtk3
  ];

  programs.fish = { # feeeeesh configs uwu
    enable = true;
    interactiveShellInit = "
      set fish_greeting
      ${pkgs.starship}/bin/starship init fish | source
    ";
  };

  programs.starship = {
    enable = true;
    settings = {
      character.success_symbol = "[➜](bold green)";
      directory.read_only = " 🥺";
      format = "$directory$git_branch \n$character";
      
    };
  };

  wayland.windowManager.sway = {
    enable = true;  
    config = {
      terminal = "alacritty";
      window.border = 1;
      colors.focused = {
        background = "#282828";
        text = "#d3869b";
        childBorder = "#d3869b";
        indicator = "b16286";
        border = "#d3869b";
      };
      gaps = {
        inner = 10;
      };
      bars = [];
      startup = [
        { command = "waybar"; }
        { command = "swaybg -i ~/Pictures/wallgockers/lain.png";}
      ];
      window.titlebar = false;
      keybindings = {
        "Ctrl+Alt+1" = "workspace 1";
        "Ctrl+Alt+2" = "workspace 2";
        "Ctrl+Alt+3" = "workspace 3";
        "Ctrl+Alt+4" = "workspace 4";

       "Ctrl+Alt+Shift+1" = "move container to workspace 1";                
       "Ctrl+Alt+Shift+2" = "move container to workspace 2";
       "Ctrl+Alt+Shift+3" = "move container to workspace 3";
       "Ctrl+Alt+Shift+4" = "move container to workspace 4";
       
       "mod4+f" = "fullscreen";
       "Ctrl+Alt+f" = "floating toggle";
                
        "Ctrl+Alt+w" = "kill";
        "Ctrl+Alt+Shift+c" = "reload";
        "mod4+Return" = "exec alacritty";
        "mod1+Space" = "exec rofi -show drun";
      };
      input = {
        "*" = {
          xkb_layout = "it";
          "natural_scroll" = "enabled";
        };
      };
    };
  };

  programs.waybar = {
    enable = true;
    package = pkgs.waybar;
    settings = {
      bar = {
        layer = "top";
        position = "top";
        height = 24;

        modules-left = ["sway/workspaces"];
        modules-center = ["sway/window"];
        modules-right = ["pulseaudio" "battery" "clock"];

        pulseaudio = {
          format = "v: {volume}%";
        };

        battery = {
          format = "b: {capacity}%";
        };
        
      };
    };
    style = "
      * {
        font-family: jetbrains mono;
        background-color: #282828;
        color: #ebdbb2;
      }

      #workspaces button, #workspaces button:hover {
        border: none;
        border-radius : unset;
        background: unset;
      }

      #workspaces button.focused {
        color: #d3869b;
      }
      #battery {
        padding-left: 10px;
        padding-right: 10px;
        background-color: #504945;
      }
      
      #clock {
        padding-left: 10px;
        padding-right: 10px;
        background-color: #3c3836;
      }

      #pulseaudio {
        padding-left: 10px;
        padding-right: 10px;
        background-color: #665c54;
      }
      
    ";
  };

  services.mako = {
    enable = true;
  }; 

  # the trans is real
  programs.hyfetch = {
    enable = true;
    settings = {
      preset = "transgender";
      mode = "rgb";
      color_align = {
        mode = "horizontal";
      };
    };
  };
  
  programs.vscode = {
    enable = true;
    package = pkgs.vscodium;
  };

  # no touchy, things go breaky
  home.stateVersion = "23.05";
  
}
